==> snpMatrix_1.8.0.tar.gz: snpMatrix/man/row.summary.Rd <==
\name{row.summary}
\alias{row.summary}
\alias{col.summary}
\title{Summarize rows or columns of a snp matrix}
\description{
  These function calculates summary statistics of each row or column of
  call rates and heterozygosity for each row of a an
  object of class \code{"snp.matrix"} or \code{"X.snp.matrix"}
}
\usage{
row.summary(object)
col.summary(object)
}
\arguments{
\item{object}{genotype data as a \code{\link{snp.matrix-class}} or \code{\link{X.snp.matrix-class}} object}
}
\value{
  \item{row.summary}{
    returns a data frame with rows corresponding to rows of the input object
    and with columns/elements:
    \itemize{
      \item{Call.rate }{Proportion of SNPs called}
      \item{Heterozygosity}{Proportion of called SNPs which are
	heterozygous}
    }
  }
  \item{col.summary}{
    returns a data frame with rows corresponding to columns of the input object
    and with columns/elements:
    \itemize{
      \item{Calls}{The number of valid calls}
      \item{Call rate}{The proportion of genotypes called}
      \item{MAF}{The minor allele frequency}
      \item{P.AA}{The frequency of homozygous genotype 1 (A/A)}
      \item{P.AB}{The frequency of heterozygous genotype 2 (A/B)}
      \item{P.BB}{The frequency of homozygous genotype 3 (B/B)}
      \item{z.HWE}{A z-test for Hardy-Weinberg equilibrium}
    }
    For objects of class \code{"X.snp.matrix"}, the following
    additional columns are returned:
    \itemize{
      \item{P.AY}{The frequency of allele A in males}
      \item{P.BY}{The frequency of allele B in males}
      \item{Calls.female}{The number of valid calls in females (only
	these calls are used in the z-test for HWE)}
    }
  }
}
\note{The current version of \code{row.summary}
  does not deal with the X chromosome
  differently, so that males are counted as homozygous.}
\author{David Clayton \email{david.clayton@cimr.cam.ac.uk}}
\examples{
data(testdata)
rs <- row.summary(Autosomes)
summary(rs)
cs <- col.summary(Autosomes)
summary(cs)
cs <- col.summary(Xchromosome)
summary(cs)
}
\keyword{utilities}

==> snpMatrix_1.16.5.tar.gz: snpMatrix/man/row.summary.Rd <==
\name{row.summary}
\alias{row.summary}
\alias{col.summary}
\title{Summarize rows or columns of a snp matrix}
\description{
  These function calculates summary statistics of each row or column of
  call rates and heterozygosity for each row of a an
  object of class \code{"snp.matrix"} or \code{"X.snp.matrix"}
}
\usage{
row.summary(object)
col.summary(object)
}
\arguments{
\item{object}{genotype data as a \code{\link{snp.matrix-class}} or \code{\link{X.snp.matrix-class}} object}
}
\value{
  \item{row.summary}{
    returns a data frame with rows corresponding to rows of the input object
    and with columns/elements:
    \itemize{
      \item Call.rate: Proportion of SNPs called
      \item Heterozygosity: Proportion of called SNPs which are
	  heterozygous
    }
  }
  \item{col.summary}{
    returns a data frame with rows corresponding to columns of the input object
    and with columns/elements:
    \itemize{
      \item Calls: The number of valid calls
      \item Call rate: The proportion of genotypes called
      \item MAF: The minor allele frequency
      \item P.AA: The frequency of homozygous genotype 1 (A/A)
      \item P.AB: The frequency of heterozygous genotype 2 (A/B)
      \item P.BB: The frequency of homozygous genotype 3 (B/B)
      \item z.HWE: A z-test for Hardy-Weinberg equilibrium
    }
    For objects of class \code{"X.snp.matrix"}, the following
    additional columns are returned:
    \itemize{
      \item P.AY: The frequency of allele A in males
      \item P.BY: The frequency of allele B in males
      \item Calls.female: The number of valid calls in females (only
	  these calls are used in the z-test for HWE)
    }
  }
}
\note{The current version of \code{row.summary}
  does not deal with the X chromosome
  differently, so that males are counted as homozygous.}
\author{David Clayton \email{david.clayton@cimr.cam.ac.uk}}
\examples{
data(testdata)
rs <- row.summary(Autosomes)
summary(rs)
cs <- col.summary(Autosomes)
summary(cs)
cs <- col.summary(Xchromosome)
summary(cs)
}
\keyword{utilities}
